@@ -417,7 +417,7 @@ ra_forward_call(INTERNAL_FUNCTION_PARAMETERS, RedisArray *ra, const char *cmd, i
 
     /* multi/exec */
     if(ra->z_multi_exec) {
-        ra_call_user_function(&redis_ce->function_table, ra->z_multi_exec, &z_fun, return_value, argc, z_callargs);
+        call_user_function(&redis_ce->function_table, ra->z_multi_exec, &z_fun, return_value, argc, z_callargs);
         zval_dtor(return_value);
         zval_dtor(&z_fun);
         for (i = 0; i < argc; ++i) {
@@ -435,7 +435,7 @@ ra_forward_call(INTERNAL_FUNCTION_PARAMETERS, RedisArray *ra, const char *cmd, i
         /* add MULTI + SADD */
         ra_index_multi(redis_inst, MULTI);
         /* call using discarded temp value and extract exec results after. */
-        ra_call_user_function(&redis_ce->function_table, redis_inst, &z_fun, return_value, argc, z_callargs);
+        call_user_function(&redis_ce->function_table, redis_inst, &z_fun, return_value, argc, z_callargs);
         zval_dtor(return_value);
 
         /* add keys to index. */
@@ -444,7 +444,7 @@ ra_forward_call(INTERNAL_FUNCTION_PARAMETERS, RedisArray *ra, const char *cmd, i
         /* call EXEC */
         ra_index_exec(redis_inst, return_value, 0);
     } else { /* call directly through. */
-        ra_call_user_function(&redis_ce->function_table, redis_inst, &z_fun, return_value, argc, z_callargs);
+        call_user_function(&redis_ce->function_table, redis_inst, &z_fun, return_value, argc, z_callargs);
 
         if (!b_write_cmd) {
             /* check if we have an error. */
@@ -662,7 +662,7 @@ multihost_distribute_call(RedisArray *ra, zval *return_value, zval *z_fun, int a
     /* Iterate our RedisArray nodes */
     for (i = 0; i < ra->count; ++i) {
         /* Call each node in turn */
-        ra_call_user_function(&redis_array_ce->function_table, &ra->redis[i], z_fun, &z_tmp, argc, argv);
+        call_user_function(&redis_array_ce->function_table, &ra->redis[i], z_fun, &z_tmp, argc, argv);
 
         /* Add the result for this host */
         add_assoc_zval_ex(return_value, ZSTR_VAL(ra->hosts[i]), ZSTR_LEN(ra->hosts[i]), &z_tmp);
@@ -975,7 +975,7 @@ PHP_METHOD(RedisArray, mget)
         /* prepare call */
         ZVAL_STRINGL(&z_fun, "MGET", 4);
         /* call MGET on the node */
-        ra_call_user_function(&redis_ce->function_table, &ra->redis[n], &z_fun, &z_ret, 1, &z_argarray);
+        call_user_function(&redis_ce->function_table, &ra->redis[n], &z_fun, &z_ret, 1, &z_argarray);
         zval_dtor(&z_fun);
 
         /* cleanup args array */
@@ -1119,7 +1119,7 @@ PHP_METHOD(RedisArray, mset)
         ZVAL_STRINGL(&z_fun, "MSET", 4);
 
         /* call */
-        ra_call_user_function(&redis_ce->function_table, &ra->redis[n], &z_fun, &z_ret, 1, &z_argarray);
+        call_user_function(&redis_ce->function_table, &ra->redis[n], &z_fun, &z_ret, 1, &z_argarray);
         zval_dtor(&z_fun);
         zval_dtor(&z_ret);
 
@@ -1251,7 +1251,7 @@ static void ra_generic_del(INTERNAL_FUNCTION_PARAMETERS, char *kw, int kw_len) {
         }
 
         /* call */
-        ra_call_user_function(&redis_ce->function_table, &ra->redis[n], &z_fun, &z_ret, 1, &z_argarray);
+        call_user_function(&redis_ce->function_table, &ra->redis[n], &z_fun, &z_ret, 1, &z_argarray);
 
         if(ra->index) {
             zval_dtor(&z_ret);
